@@ -21,9 +21,11 @@
 #define _EDIT_C THIS_IS
 
 #include <config.h>
-#if defined(OS2_NT)
+#if defined(NEEDS_IO_H)
 #    include <io.h>
-#    include <fcntl.h>
+#endif
+#include <fcntl.h>
+#ifdef NEEDS_CR_LF_TRANSLATION
 #    define CR_LF_TRANSLATION
 #endif
 #include "edit.h"
@@ -255,7 +257,7 @@ int edit_load_file (WEdit * edit, const char *filename, const char *text, unsign
 #if defined CR_LF_TRANSLATION
 	if(file && (!text)){
 		real_size=0;
-		tmp_buf[1024]=0;
+		tmp_buf[sizeof (tmp_buf)-1]=0;
 		while((bytes_read = read(file,tmp_buf,1024)) > 0){
 			real_size += bytes_read;
 		}
