@@ -139,7 +139,7 @@
 
 #include "popt.h"
 
-/* "$Id: main.c,v 1.76 1999/02/03 23:19:41 norbert Exp $" */
+/* "$Id: main.c,v 1.78 1999/02/15 21:19:29 unammx Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -349,6 +349,9 @@ char cmd_buf [512];
 /* Used during argument processing */
 int finish_program = 0;
 
+/* If set, then no windows are displayed in the GNOME edition */
+int   nowindows = 0;
+
 /* Forward declarations */
 char *get_mc_lib_dir ();
 int panel_event    (Gpm_Event *event, WPanel *panel);
@@ -1631,7 +1634,7 @@ static void do_suspend_cmd (void)
     if (console_flag && !use_subshell)
 	restore_console ();
 
-#ifndef OS2_NT
+#ifdef SIGTSTP
     {
 	struct sigaction sigtstp_action;
 	
@@ -2164,8 +2167,14 @@ mc_maybe_editor_or_viewer (void)
 #ifdef USE_INTERNAL_EDIT
     else {
 	    path = prepend_cwd_on_local ("");
+#ifndef HAVE_GNOME
 	    setup_dummy_mc (path);
+#endif
 	    edit (edit_one_file, 1);
+#ifdef HAVE_GNOME
+	    gtk_main ();
+	    exit (1);
+#endif
     }
 #endif
     g_free (path);
@@ -2372,9 +2381,11 @@ sigchld_handler_no_subshell (int sig)
     if (pid == cons_saver_pid){
 	/* {{{ Someone has stopped or killed cons.saver; restart it */
 
+#  ifdef SIGTSTP
 	if (WIFSTOPPED (status))
 	    kill (pid, SIGCONT);
 	else
+#  endif
 	{
 	    handle_console (CONSOLE_DONE);
 	    handle_console (CONSOLE_INIT);
@@ -2606,7 +2617,6 @@ static void parse_an_arg (poptContext state,
 #endif
 
 char *cmdline_geometry = NULL;
-int   nowindows = 0;
 char **directory_list = NULL;
 int   force_activation = 0;
 
